<?php

declare(strict_types=1);

namespace Drupal\media_contextual_crop;

use Drupal\image\Plugin\Field\FieldType\ImageItem;

/**
 * Interface for media_contextual_crop_use_case plugins.
 */
interface MediaContextualCropUseCaseInterface {

  /**
   * Returns the translated plugin label.
   *
   * @return string
   *   The translated title.
   */
  public function label();

  /**
   * The Plugin is competent to process this image.
   *
   * @param \Drupal\image\Plugin\Field\FieldType\ImageItem $item
   *   Image Item.
   *
   * @return bool
   *   True or false.
   */
  public function isCompetent(ImageItem $item);

  /**
   * Process image URL.
   *
   * @param \Drupal\image\Plugin\Field\FieldType\ImageItem $item
   *   Image Item Data.
   * @param string $old_uri
   *   Uri of current image.
   * @param string $image_style
   *   Image style to apply.
   *
   * @return string
   *   Url to use.
   */
  public function getContextualUri(ImageItem $item, $old_uri, $image_style);

}
